module OrientDb
  class ComplaintRepository < Base
    include OrientDb::Methods::EdgeMethods
    include RepositoriesProxy

    def report(complaint)
      create(complaint) if can_report? complaint
    end

    def destroy(user_rid, object_rid)
      if !edge_exists?(odb_class, user_rid, object_rid)
        raise "The object has not been reported by you yet."
      end

      destroy_edge 'Complaint', user_rid, object_rid
    end

    ##
    #checks if user can report a object
    #returns bool
    def can_report?(complaint)
      !edge_exists?(odb_class, complaint.user.rid, complaint.object)
    end

    ##
    #overwriting OrientDb::Base#create method
    def create(complaint)
      if complaint.valid?
        create_and_set_edge('Complaint', complaint.user.rid, complaint.object, complaint.to_orientdb_hash)
        return true
      end
      false
    end

  end
end
